@@ -1,6 +1,6 @@
 package Net::CLI::Interact::Role::Prompt;
 BEGIN {
-  $Net::CLI::Interact::Role::Prompt::VERSION = '1.110911';
+  $Net::CLI::Interact::Role::Prompt::VERSION = '1.111150';
 }
 
 use Moose::Role;
@@ -19,6 +19,7 @@ has '_prompt' => (
     isa => 'Maybe[RegexpRef]',
     required => 0,
     reader => 'prompt_re',
+    predicate => 'has_set_prompt',
     clearer => 'unset_prompt',
     trigger => sub {
         (shift)->logger->log('prompt', 'info', 'prompt has been set to', (shift));
@@ -26,10 +27,8 @@ has '_prompt' => (
 );
 
 sub set_prompt {
-    my ($self, $prompt) = @_;
-    confess "unknown prompt: [$prompt]"
-        unless eval { $self->phrasebook->prompt($prompt) };
-    $self->_prompt( $self->phrasebook->prompt($prompt)->first->value );
+    my ($self, $name) = @_;
+    $self->_prompt( $self->phrasebook->prompt($name)->first->value );
 }
 
 sub last_prompt {
@@ -38,21 +37,29 @@ sub last_prompt {
 }
 
 sub last_prompt_re {
-    my $prompt = (shift)->last_prompt;
+    my $self = shift;
+    my $prompt = $self->last_prompt;
     return qr/^\Q$prompt\E$/;
 }
 
+sub prompt_looks_like {
+    my ($self, $name) = @_;
+    return ($self->last_prompt
+        =~ $self->phrasebook->prompt($name)->first->value);
+}
+
 # pump until any of the prompts matches the output buffer
 sub find_prompt {
-    my ($self, $tries) = @_;
+    my ($self, $wake_up) = @_;
     $self->logger->log('prompt', 'notice', 'finding prompt');
 
     # make connection on transport if not yet done
     $self->transport->connect if not $self->transport->done_connect;
 
     eval {
-        while ($self->transport->harness->pump) {
-            foreach my $prompt (keys %{ $self->phrasebook->prompt }) {
+        PUMPING: while (1) {
+            $self->transport->harness->pump;
+            foreach my $prompt ($self->phrasebook->prompt_names) {
                 # prompts consist of only one match action
                 if ($self->transport->out =~ $self->phrasebook->prompt($prompt)->first->value) {
                     $self->logger->log('prompt', 'info', "hit, matches prompt $prompt");
@@ -64,18 +71,23 @@ sub find_prompt {
                         ] })
                     );
                     $self->set_prompt($prompt);
-                    return;
+                    last PUMPING;
                 }
                 $self->logger->log('prompt', 'debug', "nope, doesn't (yet) match $prompt");
             }
+            $self->logger->log('prompt', 'debug', 'no match so far, more data?');
         }
     };
-    # default call from user, $tries is zero, so run once more and inc tries
-    if ($@ and $self->has_wake_up and $tries) {
-        $self->logger->log('prompt', 'info', 'timeout, sending WAKE_UP and trying again');
+
+    if ($@ and $self->has_wake_up and $wake_up) {
+        $self->logger->log('prompt', 'info', "failed: [$@], sending WAKE_UP and trying again");
         $self->transport->send( $self->wake_up );
         $self->find_prompt;
     }
+    else {
+        $self->logger->log('prompt', 'notice', 'failed to find prompt!')
+            if not $self->has_set_prompt;
+    }
 }
 
 1;
@@ -92,7 +104,7 @@ Net::CLI::Interact::Role::Prompt - Command-line prompt management
 
 =head1 VERSION
 
-version 1.110911
+version 1.111150
 
 =head1 DESCRIPTION
 
@@ -143,6 +155,15 @@ is that the module will automatically set the Prompt for itself based on the
 last line of output received from the connected CLI. Do not use this option
 unless you know what you are doing.
 
+=head2 has_set_prompt
+
+Returns True if there is currently a Prompt set, otherwise returns False.
+
+=head2 prompt_looks_like( $name )
+
+Returns True if the current prompt matches the given named prompt. This is
+useful when you wish to make a more specific check on the current prompt.
+
 =head2 find_prompt( $wake_up? )
 
 A helper method that consumes output from the connected CLI session until a
