@@ -1,17 +1,13 @@
 package Net::CLI::Interact::Transport::Serial;
-{
-  $Net::CLI::Interact::Transport::Serial::VERSION = '1.122020_002';
+BEGIN {
+  $Net::CLI::Interact::Transport::Serial::VERSION = '1.111150';
 }
 
-use Moose;
-extends 'Net::CLI::Interact::Transport';
-
 {
     package # hide from pause
         Net::CLI::Interact::Transport::Serial::Options;
     use Moose;
     use Moose::Util::TypeConstraints qw(enum);
-    extends 'Net::CLI::Interact::Transport::Options';
 
     has 'device' => (
         is => 'rw',
@@ -47,6 +43,9 @@ extends 'Net::CLI::Interact::Transport';
 }
 # ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+use Moose;
+extends 'Net::CLI::Interact::Transport';
+
 has 'connect_options' => (
     is => 'ro',
     isa => 'Net::CLI::Interact::Transport::Serial::Options',
@@ -54,17 +53,23 @@ has 'connect_options' => (
     required => 1,
 );
 
+has 'app' => (
+    is => 'ro',
+    isa => 'Str',
+    lazy_build => 1,
+);
+
 sub _build_app {
     my $self = shift;
     confess "please pass location of plink.exe in 'app' parameter to new()\n"
-        if $self->is_win32;
+        if $^O eq 'MSWin32';
     return 'cu'; # unix
 }
 
 sub runtime_options {
     my $self = shift;
 
-    if ($self->is_win32) {
+    if ($^O eq 'mswin32') {
         return ('-serial',);
     }
     else {
@@ -91,12 +96,12 @@ Net::CLI::Interact::Transport::Serial - Serial-line based CLI connection
 
 =head1 VERSION
 
-version 1.122020_002
+version 1.111150
 
 =head1 DECRIPTION
 
-This module provides a wrapped instance of a Serial-line client for use by
-L<Net::CLI::Interact>.
+This module provides an L<IPC::Run> wrapped instance of a Serial-line client
+for use by L<Net::CLI::Interact>.
 
 =head1 INTERFACE
 
@@ -129,7 +134,7 @@ communication. The default is C<none>.
 =item nostop
 
 You can control whether to use C<XON/XOFF> handling for the serial
-communication. The default is to disable this, so to enable it pass any True
+communcation. The default is to disable this, so to enable it pass any True
 value.
 
 =item speed
@@ -137,12 +142,6 @@ value.
 You can set the speed (or I<baud rate>) of the serial line by passing a value
 to this named parameter. The default is C<9600>.
 
-=item reap
-
-Only used on Unix platforms, this installs a signal handler which attempts to
-reap the child process. Pass a true value to enable this feature only
-if you notice zombie processes are being left behind after use.
-
 =back
 
 =head1 COMPOSITION
@@ -163,7 +162,7 @@ Oliver Gorwits <oliver@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Oliver Gorwits.
+This software is copyright (c) 2011 by Oliver Gorwits.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
